{% load cms_tags i18n %}

{% if 'faq.change_faq' in perms or user.is_superuser %}
<a class="btn btn-outline-secondary mb-4" href="{% url 'admin:faq_faq_changelist' %}">{% trans "Add/Edit FAQs" %}</a>
{% endif %}
{% for faq in faq_list %}
	<div class="post">
		<a name="faq_item_{{ faq.id }}"></a>
		<h2 class='faq-question post-title'>{% render_model faq "question" %}</h2>
		<div class='faq-answer post-body'>
			{% render_model faq "answer" "" "" "safe" %}
		</div>
	</div>
{% endfor %}
