# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-07-20 16:43
from __future__ import unicode_literals

from django.db import migrations, models
import djangocms_text_ckeditor.fields


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0009_auto_20170719_1720'),
    ]

    operations = [
        migrations.AlterField(
            model_name='emailtemplate',
            name='content',
            field=models.TextField(blank=True, help_text='See the list of available variables for details on what information can be included with template tags.', null=True, verbose_name='Plain text Content'),
        ),
        migrations.AlterField(
            model_name='emailtemplate',
            name='html_content',
            field=djangocms_text_ckeditor.fields.HTMLField(blank=True, help_text='Emails are sent as plain text by default.  To send an HTML email instead, enter your desired content in this field.', null=True, verbose_name='HTML rich text content'),
        ),
    ]
