# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-09-09 04:24
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0016_auto_20170830_1159'),
    ]

    operations = [
        migrations.AlterField(
            model_name='cashpaymentrecord',
            name='collectedByUser',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='collectedcashpayments', to=settings.AUTH_USER_MODEL, verbose_name='Collected by user'),
        ),
        migrations.AlterField(
            model_name='classdescription',
            name='danceTypeLevel',
            field=models.ForeignKey(default=1, on_delete=django.db.models.deletion.SET_DEFAULT, to='core.DanceTypeLevel', verbose_name='Dance Type & Level'),
        ),
        migrations.AlterField(
            model_name='customer',
            name='user',
            field=models.OneToOneField(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL, verbose_name='User account'),
        ),
        migrations.AlterField(
            model_name='emailtemplate',
            name='groupRequired',
            field=models.ForeignKey(blank=True, help_text='Some templates should only be visible to some users.', null=True, on_delete=django.db.models.deletion.SET_NULL, to='auth.Group', verbose_name='Group permissions required to use.'),
        ),
        migrations.AlterField(
            model_name='event',
            name='location',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='core.Location', verbose_name='Location'),
        ),
        migrations.AlterField(
            model_name='event',
            name='room',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='core.Room', verbose_name='Room'),
        ),
        migrations.AlterField(
            model_name='event',
            name='submissionUser',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='eventsubmissions', to=settings.AUTH_USER_MODEL, verbose_name='Submitted by user'),
        ),
        migrations.AlterField(
            model_name='eventlistpluginmodel',
            name='location',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='core.Location', verbose_name='Limit to location'),
        ),
        migrations.AlterField(
            model_name='eventregistration',
            name='role',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='core.DanceRole', verbose_name='Dance role'),
        ),
        migrations.AlterField(
            model_name='eventstaffmember',
            name='category',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='core.EventStaffCategory', verbose_name='Category'),
        ),
        migrations.AlterField(
            model_name='eventstaffmember',
            name='replacedStaffMember',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='replacementFor', to='core.EventStaffMember', verbose_name='Replacement for'),
        ),
        migrations.AlterField(
            model_name='eventstaffmember',
            name='submissionUser',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL, verbose_name='Submission User'),
        ),
        migrations.AlterField(
            model_name='instructorlistpluginmodel',
            name='imageThumbnail',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='filer.ThumbnailOption', verbose_name='Image thumbnail option'),
        ),
        migrations.AlterField(
            model_name='invoice',
            name='collectedByUser',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='collectedinvoices', to=settings.AUTH_USER_MODEL, verbose_name='Collected by user'),
        ),
        migrations.AlterField(
            model_name='invoice',
            name='finalRegistration',
            field=models.OneToOneField(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='core.Registration', verbose_name='Registration'),
        ),
        migrations.AlterField(
            model_name='invoice',
            name='submissionUser',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='submittedinvoices', to=settings.AUTH_USER_MODEL, verbose_name='Registered by user'),
        ),
        migrations.AlterField(
            model_name='invoiceitem',
            name='finalEventRegistration',
            field=models.OneToOneField(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='core.EventRegistration', verbose_name='Event registration'),
        ),
        migrations.AlterField(
            model_name='paymentrecord',
            name='invoice',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='core.Invoice', verbose_name='Invoice'),
        ),
        migrations.AlterField(
            model_name='paymentrecord',
            name='submissionUser',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='payments_submitted', to=settings.AUTH_USER_MODEL, verbose_name='Submission user'),
        ),
        migrations.AlterField(
            model_name='publicevent',
            name='category',
            field=models.ForeignKey(blank=True, help_text='Custom event categories may be used to display special types of events (e.g. practice sessions) separately on your registration page.  They may also be displayed in different colors on the public calendar.', null=True, on_delete=django.db.models.deletion.SET_NULL, to='core.PublicEventCategory', verbose_name='Category (optional)'),
        ),
        migrations.AlterField(
            model_name='publicevent',
            name='pricingTier',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='core.PricingTier', verbose_name='Pricing Tier'),
        ),
        migrations.AlterField(
            model_name='series',
            name='category',
            field=models.ForeignKey(blank=True, help_text='Custom series categories may be used to display special series (e.g. one-offs, visiting instructors) separately on your registration page.', null=True, on_delete=django.db.models.deletion.SET_NULL, to='core.SeriesCategory', verbose_name='Series category (optional)'),
        ),
        migrations.AlterField(
            model_name='series',
            name='classDescription',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='core.ClassDescription', verbose_name='Class description'),
        ),
        migrations.AlterField(
            model_name='series',
            name='pricingTier',
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='core.PricingTier', verbose_name='Pricing tier'),
        ),
        migrations.AlterField(
            model_name='staffmember',
            name='userAccount',
            field=models.OneToOneField(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL, verbose_name='User account'),
        ),
        migrations.AlterField(
            model_name='temporaryeventregistration',
            name='role',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='core.DanceRole', verbose_name='Dance role'),
        ),
        migrations.AlterField(
            model_name='temporaryregistration',
            name='submissionUser',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='submittedtemporaryregistrations', to=settings.AUTH_USER_MODEL, verbose_name='registered by user'),
        ),
    ]
