# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-08-30 15:59
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0015_auto_20170829_1301'),
    ]

    operations = [
        migrations.RenameField(
            model_name='pricingtier',
            old_name='doorGeneralPrice',
            new_name='doorPrice',
        ),
        migrations.RenameField(
            model_name='pricingtier',
            old_name='onlineGeneralPrice',
            new_name='onlinePrice',
        ),
        migrations.RemoveField(
            model_name='pricingtier',
            name='doorStudentPrice',
        ),
        migrations.RemoveField(
            model_name='pricingtier',
            name='onlineStudentPrice',
        ),
        migrations.AlterField(
            model_name='invoice',
            name='temporaryRegistration',
            field=models.OneToOneField(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='core.TemporaryRegistration', verbose_name='Temporary registration'),
        ),
        migrations.AlterField(
            model_name='invoiceitem',
            name='temporaryEventRegistration',
            field=models.OneToOneField(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='core.TemporaryEventRegistration', verbose_name='Temporary event registration'),
        ),
        migrations.AlterField(
            model_name='registration',
            name='temporaryRegistration',
            field=models.OneToOneField(null=True, on_delete=django.db.models.deletion.SET_NULL, to='core.TemporaryRegistration', verbose_name='Associated temporary registration'),
        ),
    ]
