# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-09-11 03:52
from __future__ import unicode_literals

from django.db import migrations, models
import jsonfield.fields


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0017_auto_20170909_0024'),
    ]

    operations = [
        migrations.AlterField(
            model_name='invoice',
            name='data',
            field=jsonfield.fields.JSONField(blank=True, default={}, verbose_name='Additional data'),
        ),
        migrations.AddField(
            model_name='invoice',
            name='email',
            field=models.CharField(blank=True, max_length=200, null=True, verbose_name='Recipient email address'),
        ),
        migrations.AddField(
            model_name='invoice',
            name='firstName',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Recipient first name'),
        ),
        migrations.AddField(
            model_name='invoice',
            name='lastName',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Recipient last name'),
        ),
        migrations.AlterField(
            model_name='customer',
            name='data',
            field=jsonfield.fields.JSONField(blank=True, default={}, verbose_name='Additional data'),
        ),
        migrations.AlterField(
            model_name='eventregistration',
            name='data',
            field=jsonfield.fields.JSONField(blank=True, default={}, verbose_name='Additional data'),
        ),
        migrations.AlterField(
            model_name='registration',
            name='data',
            field=jsonfield.fields.JSONField(blank=True, default={}, verbose_name='Additional data'),
        ),
        migrations.AlterField(
            model_name='temporaryeventregistration',
            name='data',
            field=jsonfield.fields.JSONField(blank=True, default={}, verbose_name='Additional data'),
        ),
        migrations.AlterField(
            model_name='temporaryregistration',
            name='data',
            field=jsonfield.fields.JSONField(blank=True, default={}, verbose_name='Additional data'),
        ),
    ]
