# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-10-03 19:22
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0019_invoice_buyerpayssalestax'),
        ('discounts', '0005_auto_20170830_1159'),
    ]

    operations = [
        migrations.CreateModel(
            name='CustomerDiscount',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('customer', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='core.Customer', verbose_name='Customer')),
                ('discountCombo', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='discounts.DiscountCombo', verbose_name='Discount')),
            ],
            options={
                'verbose_name_plural': 'Customer-specific discount restrictions',
                'verbose_name': 'Customer-specific discount restriction',
            },
        ),
    ]
