{% extends "cms/admin_home.html" %}
{% load danceschool_tags i18n %}

{% block content %}
<div class="selectclass">
    <h2>{% trans "Select an Event to View Registrations" %}</h2>
        {% for event in event_list %}
            {% ifchanged event.month %}
                {% if not forloop.first %}</ul>{% endif %}
                <h4>{{ event.month|readable_month }} {{ event.year }}</h4>
            <ul>
            {% endifchanged %}
            <li><a href="{% url 'viewregistrations' event.id %}">{{ event.name }}</a>:&nbsp;&nbsp;{{ event.startTime|date:'l, h:i A' }}</li>
        {% if forloop.last %}</ul>{% endif %}
        {% empty %}
        <li>{% trans "No classes or events yet. Check back soon!" %}</li>
        {% endfor %}
    </ul>
</div>
{% endblock %}
